# propsettings_qt

This package provides a mechanism of automatic PySide2 (Qt) widget generation to edit member variables of an object.
The variables should be registered as a propsettings.Setting. See [propsettings](https://github.com/mnicolas94/propsettings) for more information.